@@ -18,7 +18,7 @@ check_chr <- function(x,
                          coerce = FALSE,
                          x_name = substitute(x),
                          error = TRUE) {
-  x_name <- deparse_x_name(x_name)
+  x_name <- chk_deparse(x_name)
   
   check_flag_internal(coerce)
   check_flag_internal(error)
@@ -36,7 +36,7 @@ check_string <- function(x,
                          coerce = FALSE,
                          x_name = substitute(x),
                          error = TRUE) {
-  x_name <- deparse_x_name(x_name)
+  x_name <- chk_deparse(x_name)
   
   check_chr(x, coerce = coerce, x_name = x_name, error = error)
 }
