@@ -40,7 +40,7 @@ check_data <- function(x,
                        key = character(0),
                        x_name = substitute(x),
                        error = TRUE) {
-  x_name <- deparse_x_name(x_name)
+  x_name <- chk_deparse(x_name)
   
   check_inherits(x, "data.frame", x_name = x_name)
 
