@@ -14,7 +14,7 @@
 check_environment <- function(x, 
                            x_name = substitute(x),
                            error = TRUE) {
-  x_name <- deparse_x_name(x_name)
+  x_name <- chk_deparse(x_name)
   check_flag_internal(error)
   
   if (!is.environment(x)) chk_fail(x_name, " must be an environment", error = error)
