@@ -16,7 +16,7 @@ check_function <- function(x,
                            nargs = NA,
                            x_name = substitute(x),
                            error = TRUE) {
-  x_name <- deparse_x_name(x_name)
+  x_name <- chk_deparse(x_name)
   
   check_length_internal(nargs)
 
