@@ -22,7 +22,7 @@ check_homogenous <- function(x,
                              recursive = FALSE,
                              x_name = substitute(x),
                              error = TRUE) {
-  x_name <- deparse_x_name(x_name)
+  x_name <- chk_deparse(x_name)
   
   check_flag_internal(strict)
   check_flag_internal(recursive)
