@@ -17,7 +17,7 @@ check_nlevels <- function(x,
                          nlevels = TRUE,
                          x_name = substitute(x),
                          error = TRUE) {
-  x_name <- deparse_x_name(x_name)
+  x_name <- chk_deparse(x_name)
 
   check_length_internal(nlevels)
 
