@@ -11,7 +11,7 @@ check_props <- function(x, x_name = substitute(x),
                        error = TRUE) {
   .Deprecated()
   
-  x_name <- deparse_x_name(x_name)
+  x_name <- chk_deparse(x_name)
 
   check_flag_internal(error)
   
